from django.db import models
from django.contrib.auth import get_user_model

User = get_user_model()


class LogEntry(models.Model):
    ACTION_CHOICES = [
        ("apply_resume", "申请查看简历"),
        ("approve_resume", "审批简历申请"),
        ("manual_grant_resume", "手动授权简历"),
        ("apply_website", "申请访问网站"),
        ("approve_website", "审批网站申请"),
        ("manual_grant_website", "手动授权网站"),
    ]

    user = models.ForeignKey(User, on_delete=models.SET_NULL, null=True, related_name="operation_logs",
                             verbose_name="操作者")
    action = models.CharField(max_length=50, choices=ACTION_CHOICES, verbose_name="操作类型")
    target_type = models.CharField(max_length=50, verbose_name="目标类型", help_text="如 resume, website")
    target_id = models.IntegerField(verbose_name="目标ID")
    message = models.TextField(blank=True, verbose_name="说明")
    created_at = models.DateTimeField(auto_now_add=True, verbose_name="操作时间")

    class Meta:
        verbose_name = "操作日志"
        verbose_name_plural = "操作日志"
        ordering = ["-created_at"]

    def __str__(self):
        return f"[{self.get_action_display()}] {self.user} -> {self.target_type}#{self.target_id}"
